@@ -3,31 +3,41 @@
 ##############################################################
 ##   snuggle - CellID to Geolocation using google's APIs    ##
 ##############################################################
+# get cellid codes via dbus command
+#     MCC   :   Mobile Country Code;	
+#     MNC   :   Mobile Network Code;
+#     LAC   :   Local Area Code; 	
+#     CellID:   Cellid;
+##############################################################
+
+
 # Copyright (c) 2011 Christos Zamantzas
 # Licenced under GPLv2
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.4-1'
+Version = '1.6-1'
 
-# get cellid codes via dbus command
-    # MCC:	Mobile Country Code;	
-    # MNC:	Mobile Network Code;
-    # LAC:	Local Area Code; 	
-    # CELLID:	Cellid;
 
+# standard modules
+import os
+import sys
+import time
+
+# access modules
 from struct import pack, unpack
 from httplib import HTTP
 import urllib2
 import urllib
-import os
-import sys
 
+# GUI modules
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import *
 
+# GUI model
 from snuggleUI import *
 
+# Constants 
 country         = "en"
 device          = "Nokia-N900-M5"
 user_agent      = 'Mozilla/4.0 (compatible; MSIE 5.5; Windows NT)'
@@ -43,14 +53,55 @@ dbus_cellid     = 'dbus-send --system --print-reply=literal\
                             --type=method_call\
                             --dest=com.nokia.phone.net\
                             /com/nokia/phone/net Phone.Net.get_registration_status'
+
+# application paths and names                             
 LogPath         = '/home/user/.snuggle'
 MapName         = 'map.png'
+LogCellInfo     = 'cellInfo.txt'
+LogGeoInfo      = 'geoLocation.txt'
+
+def GetTime():
+    '''Convert time to readable format.'''
+
+    t = time.localtime( time.time() )
+
+    if t[2] <= 9:
+        t2 = '0' + str(t[2])
+    else:
+        t2 = t[2]
+
+    if t[1] <= 9:
+        t1 = '0' + str(t[1])
+    else:
+        t1 = t[1]
+
+    if t[0] <= 9:
+        t0 = '0' + str(t[0])
+    else:
+        t0 = t[0]
+
+    if t[3] <= 9:
+        t3 = '0' + str(t[3])
+    else:
+        t3 = t[3]
+
+    if t[4] <= 9:
+        t4 = '0' + str(t[4])
+    else:
+        t4 = t[4]
+
+    if t[5] <= 9:
+        t5 = '0' + str(t[5])
+    else:
+        t5 = t[5]
+    
+    return "%s%s%s_%s_%s_%s" % (t0, t1, t2, t3, t4, t5)
 
 def checkFile(Path, File):       
     ''' Check if a file exists. '''
 
     try:
-        f = open(Path + File, 'r')
+        f = open(Path + '/' + File, 'r')
         f.close()
     except:
         return False
@@ -153,49 +204,52 @@ class snuggleAbout(QtGui.QMainWindow): #FIXME: update info, icon, URLs
  
 class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
 
-     def __init__(self, parent=None):
+    def __init__(self, parent=None):
          
-         ##Build parent user interface
-         QtGui.QWidget.__init__(self, parent)
-         self.ui = Ui_snuggleUI()
-         self.ui.setupUi(self)
-         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-         
-         ##Connect the GUI Buttons with actions
-           ##Create Settings
-         QtCore.QObject.connect(self.ui.btnGetCellID, QtCore.SIGNAL('clicked()'), self.doGetCellID)
-         QtCore.QObject.connect(self.ui.btnGetLocation, QtCore.SIGNAL('clicked()'), self.doGetLocation)
-         QtCore.QObject.connect(self.ui.btnSeeMap, QtCore.SIGNAL('clicked()'), self.doSeeMap)
-         QtCore.QObject.connect(self.ui.btnGoogleMaps, QtCore.SIGNAL('clicked()'), self.doOpenGoogleMaps)
-         
-           ##Connect Menu Buttons 
-         QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
-         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
-         QtCore.QObject.connect(self.ui.actionEnable_Edit_Mode, QtCore.SIGNAL('triggered()'), self.doEnableEditMode)
-         QtCore.QObject.connect(self.ui.actionDisable_Edit_Mode, QtCore.SIGNAL('triggered()'), self.doDisableEditMode)
+       #Build parent user interface
+       QtGui.QWidget.__init__(self, parent)
+       self.ui = Ui_snuggleUI()
+       self.ui.setupUi(self)
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+      
+       #Connect the GUI Buttons with actions
+       ##Create Settings
+       QtCore.QObject.connect(self.ui.btnGetCellID, QtCore.SIGNAL('clicked()'), self.doGetCellID)
+       QtCore.QObject.connect(self.ui.btnGetLocation, QtCore.SIGNAL('clicked()'), self.doGetLocation)
+       QtCore.QObject.connect(self.ui.btnSeeMap, QtCore.SIGNAL('clicked()'), self.doSeeMap)
+       QtCore.QObject.connect(self.ui.btnGoogleMaps, QtCore.SIGNAL('clicked()'), self.doOpenGoogleMaps)
+      
+       ##Connect Menu Buttons 
+       QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
+       QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
+       QtCore.QObject.connect(self.ui.actionEnable_Edit_Mode, QtCore.SIGNAL('triggered()'), self.doEnableEditMode)
+       QtCore.QObject.connect(self.ui.actionDisable_Edit_Mode, QtCore.SIGNAL('triggered()'), self.doDisableEditMode)
 
-          ## Disable all menu entries 
-         self.ui.lineCellID.setEnabled(False)
-         self.ui.lineMCC.setEnabled(False)
-         self.ui.lineMNC.setEnabled(False)
-         self.ui.lineLAC.setEnabled(False)
-         self.ui.lineLON.setEnabled(False)
-         self.ui.lineLAT.setEnabled(False)
-          ## Disable buttons that cannot be used just yet
-         self.ui.btnSeeMap.setEnabled(False)
-         self.ui.btnGoogleMaps.setEnabled(False)
-         self.ui.btnGetLocation.setEnabled(False)
-          ## Disable action buttons that cannot be used just yet
-         self.ui.actionDisable_Edit_Mode.setEnabled(False)
+       ## Disable all menu entries 
+       self.ui.lineCellID.setEnabled(False)
+       self.ui.lineMCC.setEnabled(False)
+       self.ui.lineMNC.setEnabled(False)
+       self.ui.lineLAC.setEnabled(False)
+       self.ui.lineLON.setEnabled(False)
+       self.ui.lineLAT.setEnabled(False)
+       ## Disable buttons that cannot be used just yet
+       self.ui.btnSeeMap.setEnabled(False)
+       self.ui.btnGoogleMaps.setEnabled(False)
+       self.ui.btnGetLocation.setEnabled(False)
+       ## Disable action buttons that cannot be used just yet
+       self.ui.actionDisable_Edit_Mode.setEnabled(False)
+         
+       # Populate UI with values.
+       self.doGetCellID()
 
-     ##Create Methods
-     def doAbout(self):
+    ##Create Methods
+    def doAbout(self):
     
          stackwindow = snuggleAbout(self)
          stackwindow.show()
 
-     def doEnableEditMode(self):
+    def doEnableEditMode(self):
 
          ## Enable all menu entries 
          self.ui.lineCellID.setEnabled(True)
@@ -212,7 +266,7 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
          self.ui.actionDisable_Edit_Mode.setEnabled(True)
          self.ui.actionEnable_Edit_Mode.setEnabled(False)
     
-     def doDisableEditMode(self):
+    def doDisableEditMode(self):
 
           ## Disable all menu entries 
          self.ui.lineCellID.setEnabled(False)
@@ -229,11 +283,11 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
          self.ui.actionDisable_Edit_Mode.setEnabled(False)
          self.ui.actionEnable_Edit_Mode.setEnabled(True)
      
-     def doGetCellID(self):
+    def doGetCellID(self):
          ''' Get cellid info from system'''
 
          MCC,MNC,LAC,CELLID = self.get_cellid_info()
-         print MCC, MNC, LAC, CELLID
+         print 'MCC:', MCC, ', MNC:', MNC, ', LAC: ', LAC, ', CellID:', CELLID
 
          self.ui.lineCellID.setText(str(CELLID))
          self.ui.lineMCC.setText(str(MCC))
@@ -242,7 +296,7 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
          
          self.ui.btnGetLocation.setEnabled(True)
          
-     def doGetLocation(self):
+    def doGetLocation(self):
          ''' Get coordinates from Google mmap API'''
 
          #MCC,MNC,LAC,CELLID = self.get_cellid_info()
@@ -254,7 +308,7 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
          CELLID = int(self.ui.lineCellID.text())
 
          LAT,LON,validData,message = self.get_location_by_cell(CELLID, LAC, MNC, MCC)
-         print LAT, LON
+         print 'LAT:', LAT, ', LON:', LON
 
          if validData == 'True':
              self.ui.lineLON.setText(str(LON))
@@ -266,9 +320,8 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
              pass
          
          showQuickMessage(message)
-         
-         
-     def doSeeMap(self):
+               
+    def doSeeMap(self):
          ''' Store a png from location''' 
          LAT = float(self.ui.lineLAT.text())
          LON = float(self.ui.lineLON.text())
@@ -282,17 +335,17 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
          else:
              pass
 
-     def doOpenGoogleMaps(self):
+    def doOpenGoogleMaps(self):
          ''' Open browser @ google maps @ coordinates'''
          LAT = float(self.ui.lineLAT.text())
          LON = float(self.ui.lineLON.text())
          os.system('%s"%s?q=%f,%f"' % (dbus_browser, url_map, LAT, LON))
      
-     def someother(self): #FIXME: not used atm
+    def someother(self): #FIXME: not used atm
 
          self.get_location_by_geo(LAT, LON)
 
-     def fetch_latlong_http(self, query):
+    def fetch_latlong_http(self, query):
          http = HTTP('www.google.com', 80)
          http.putrequest('POST', '/glm/mmap')
          http.putheader('Content-Type', 'application/binary')
@@ -301,24 +354,20 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
          http.send(query)
          
          code, msg, headers = http.getreply()
-         print code, msg, headers
-         
          result = http.file.read()
-         print result
          
          return result
 
-     def fetch_latlong_urllib(self, query):
+    def fetch_latlong_urllib(self, query):
          headers = { 'User-Agent' : user_agent }
          req = urllib2.Request(url_mmap, query, headers)
          resp = urllib2.urlopen(req)
          response = resp.read()
          return response
 
-     fetch_latlong = fetch_latlong_http
+    fetch_latlong = fetch_latlong_http
 
-     def get_location_by_cell(self, cid, lac, mnc=0, mcc=0, country="en"):
-         print country
+    def get_location_by_cell(self, cid, lac, mnc=0, mcc=0, country='en'):
          latitude = 0
          longitude = 0
          validData = 'False'         
@@ -339,9 +388,8 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
              try:
                  bytes = self.fetch_latlong_http(b_string)
                  #bytes = self.fetch_latlong_urllib(b_string)
-                 print bytes
                  (a, b, errorCode, latitude, longitude, c, d, e) = unpack(">hBiiiiih",bytes)
-                 print errorCode
+                 print 'ErrorCode: ', errorCode
              except:
                  message = 'WARNING: Could not get a valid responce from the MMAP API'
                  pass
@@ -351,14 +399,17 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
                  message = 'INFO: Got the LAT and LON for this cellID.'
                  validData = 'True'
                  
-         print message    
+         print message
+         
+         os.system( 'echo \"%s,%s,%s\" >> %s/%s'% ( GetTime(), latitude, longitude, LogPath, LogGeoInfo )) 
+            
          return latitude, longitude, validData, message
 
-     def get_location_by_geo(self, latitude, longitude):
+    def get_location_by_geo(self, latitude, longitude):
          url = '%s?q=%s,%s&output=json&oe=utf8' % (url_geo, str(latitude), str(longitude))
          return urllib2.urlopen(url).read()
 
-     def storeMap(self, latitude, longitude):
+    def storeMap(self, latitude, longitude):
          '''Create map of current coordinates.'''
 
          MapZoom     = 16
@@ -387,57 +438,71 @@ class snuggleMainWindow(QtGui.QMainWindow): #FIXME: cleanup of old code.
              if os.path.isfile( '%s/%s' % (LogPath, MapName) ) == True:
                  print 'INFO: created coordinate map'
                  message = 'INFO: created coordinate map'
+                 os.system( 'cp %s/%s %s/%s' % ( LogPath, MapName, LogPath, 'map_'+GetTime()+'.png' ) )
+                 
                  return True, message
              else:
                  print 'WARNING: failed to create coordinate map (file not found)'
                  message =  'WARNING: failed to create coordinate map (file not found)'
                  return False, message
  
-     def get_cellid_info(self):
-         '''Get cellid info from system'''
+    def get_cellid_info(self):
+       '''Get cellid info from system'''
          
-         info = os.popen(dbus_cellid).read().replace('   byte ','').replace('   uint32 ','').replace('   uint16 ','').replace('   int32 ','').split('\n')
-         MCC    = int(info[4])
-         MNC    = int(info[3])
-         LAC    = int(info[1])
-         CELLID = int(info[2])
-
-         return MCC, MNC, LAC, CELLID
+       info = os.popen(dbus_cellid).read().replace('   byte ','').replace('   uint32 ','').replace('   uint16 ','').replace('   int32 ','').split('\n')
+       MCC    = int(info[4])
+       MNC    = int(info[3])
+       LAC    = int(info[1])
+       CELLID = int(info[2])
 
+       os.system( 'echo \"%s,%s,%s,%s,%s\" >> %s/%s'% ( GetTime(), MCC, MNC, LAC, CELLID, LogPath, LogCellInfo )) 
+       return MCC, MNC, LAC, CELLID
+      
 class OpenImage(QtGui.QMainWindow):
     def __init__(self, parent = None):
-         imgFile = '/home/user/.snuggle/map.png'
-         QMainWindow.__init__(self,parent)
-         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-         self.setWindowTitle("Map image of location")
-         self.image = QtGui.QImage(imgFile)#.scaled(800,450,Qt.KeepAspectRatio)
-         #self.resize(self.image.size())
-
+    
+       imgFile = LogPath + "/" + MapName
+       QMainWindow.__init__(self,parent)
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+       self.setWindowTitle("Map image of location")
+       self.image = QtGui.QImage(imgFile)#.scaled(800,450,Qt.KeepAspectRatio)
+       #self.resize(self.image.size())
+          
     def paintEvent(self, event):
-         p = QtGui.QPainter(self)
-         p.drawImage(event.rect(), self.image)
+       p = QtGui.QPainter(self)
+       p.drawImage(event.rect(), self.image)
 
-         self.show()
+       self.show()
          
 class snuggleMain(): 
 
-     ##Check with what priviledges the GUI has been executed
-     if os.geteuid() == 0:
-         message = 'ERROR: The application cannot be executed as root. Exiting..'
-         showMessage(message)
-         sys.exit(1)
-     else:
-         pass
+    ##Check with what priviledges the GUI has been executed
+    if os.geteuid() == 0:
+       message = 'ERROR: The application cannot be executed as root. Exiting..'
+       showMessage(message)
+       sys.exit(1)
+    else:
+       pass
 
-     ##Check if temp folder is available
-     if os.path.exists(LogPath) == False:
-         os.system('mkdir %s' % LogPath)
-     else:
-         pass
-
-     ##Open Dialog Window
-     app = QtGui.QApplication(sys.argv)
-     myapp = snuggleMainWindow()
-     myapp.show()
-     sys.exit(app.exec_())     
\ No newline at end of file
+    ##Check if temp folder is available
+    if os.path.exists(LogPath) == False:
+       os.system('mkdir %s' % LogPath)
+    else:
+       pass
+    ##Check if log files exist
+    if checkFile(LogPath, LogCellInfo) == False:
+       os.system ( 'echo \"Time,MCC,MNC,LAC,CELLID\" > %s/%s' % (LogPath, LogCellInfo) )
+    else:
+       pass
+       
+    if checkFile(LogPath, LogGeoInfo) == False:
+       os.system ( 'echo \"Time,LAT,LON\" > %s/%s' % (LogPath, LogGeoInfo) )
+    else:
+       pass
+         
+    ##Open Dialog Window
+    app = QtGui.QApplication(sys.argv)
+    myapp = snuggleMainWindow()
+    myapp.show()
+    sys.exit(app.exec_())     
\ No newline at end of file
